Module dataset

Module dataset 

Structs

randomx_dataset

Functions

randomx_alloc_dataset
Creates a randomx_dataset structure and allocates memory for RandomX Dataset.
randomx_dataset_item_count
Gets the number of items contained in the dataset.
randomx_get_dataset_memory
Returns a pointer to the internal memory buffer of the dataset structure. The size of the internal memory buffer is randomx_dataset_item_count() * RANDOMX_DATASET_ITEM_SIZE.
randomx_init_dataset
Initializes dataset items.
randomx_release_dataset
Releases all memory occupied by the randomx_dataset structure.@param dataset is a pointer to a previously allocated randomx_dataset structure.