Structs
Functions
- randomx_
alloc_ ⚠dataset - Creates a randomx_dataset structure and allocates memory for RandomX Dataset.
- randomx_
dataset_ ⚠item_ count - Gets the number of items contained in the dataset.
- randomx_
get_ ⚠dataset_ memory - Returns a pointer to the internal memory buffer of the dataset structure. The size of the internal memory buffer is randomx_dataset_item_count() * RANDOMX_DATASET_ITEM_SIZE.
- randomx_
init_ ⚠dataset - Initializes dataset items.
- randomx_
release_ ⚠dataset - Releases all memory occupied by the randomx_dataset structure.@param dataset is a pointer to a previously allocated randomx_dataset structure.